@@ -1,36 +1,31 @@
 package MooseX::Role::WithOverloading::Meta::Role;
-our $VERSION = '0.05';
+BEGIN {
+  $MooseX::Role::WithOverloading::Meta::Role::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $MooseX::Role::WithOverloading::Meta::Role::VERSION = '0.06';
+}
 # ABSTRACT: Roles which support overloading
 
-use Moose ();
+use Moose 0.94 ();
 use Moose::Role;
 use aliased 'MooseX::Role::WithOverloading::Meta::Role::Composite', 'CompositionRole';
 use namespace::autoclean;
 
-$Moose::VERSION >= 0.9301
-    ? around composition_class_roles => sub {
-        my ($orig, $self) = @_;
-        return $self->$orig,
-            CompositionRole;
-    }
-    : has '+composition_class_roles' => (
-        default => sub { [ CompositionRole ] },
-    );
+around composition_class_roles => sub {
+    my ($orig, $self) = @_;
+    return $self->$orig, CompositionRole;
+};
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
 
 MooseX::Role::WithOverloading::Meta::Role - Roles which support overloading
 
-=head1 VERSION
-
-version 0.05
-
 =head1 AUTHORS
 
   Florian Ragwitz <rafl@debian.org>
@@ -43,6 +38,5 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
