@@ -1,5 +1,11 @@
 package MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs;
-our $VERSION = '0.05';
+BEGIN {
+  $MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs::AUTHORITY = 'cpan:FLORA';
+}
+BEGIN {
+  $MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs::VERSION = '0.06';
+}
+# ABSTRACT: Fix up magic when applying roles to instances with magic on old perls
 
 use Moose::Role;
 use namespace::autoclean;
@@ -14,24 +20,13 @@ if ($] < 5.008009) {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
 
-MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs
-
-=head1 VERSION
-
-version 0.05
-
-=begin Pod::Coverage
-
-reset_amagic
-
-=end Pod::Coverage
-
+MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs - Fix up magic when applying roles to instances with magic on old perls
 
+=for Pod::Coverage reset_amagic
 
 =head1 AUTHORS
 
@@ -45,6 +40,5 @@ This software is copyright (c) 2010 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
